pub trait Interceptable:
Send
+ Sync
+ 'static {
type Input: Send;
type Output: Send;
}Expand description
An operation that can be intercepted.
This trait defines the input and output types for an interceptable operation. Implement this for marker types that represent different domains (e.g., LLM calls, tool executions).
Required Associated Types
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".